@@ -49,6 +49,7 @@ class NetCDFDataset(torch.utils.data.Dataset):
         normalize: bool = True,
         add_position_encoding: bool = False,
         data_sources_names: Optional[list[str]] = None,
+        num_bands: int = 4,
     ):
         """
         Netcdf Dataset
@@ -70,6 +71,7 @@ class NetCDFDataset(torch.utils.data.Dataset):
             normalize: normalize the batch data
             add_position_encoding: Whether to add position encoding or not
             data_sources_names: Names of data sources to load, if not using all of them
+            num_bands: Number of bands for the Fourier features for the position encoding
         """
         self.n_batches = n_batches
         self.src_path = src_path
@@ -80,6 +82,7 @@ class NetCDFDataset(torch.utils.data.Dataset):
         self.configuration = configuration
         self.normalize = normalize
         self.add_position_encoding = add_position_encoding
+        self.num_bands = num_bands
         if data_sources_names is None:
             data_sources_names = list(Example.__fields__.keys())
         self.data_sources_names = data_sources_names
@@ -167,7 +170,9 @@ class NetCDFDataset(torch.utils.data.Dataset):
                 current_timestep_index=self.current_timestep_5_index,
             )
         if self.add_position_encoding:
-            position_encodings = generate_position_encodings_for_batch(batch, num_bands=16)
+            position_encodings = generate_position_encodings_for_batch(
+                batch, num_bands=self.num_bands
+            )
         # change batch into ML learning batch ready for training
         batch: BatchML = BatchML.from_batch(batch=batch)
 
